@@ -10,6 +10,8 @@ use namespace::clean;
 
 use App::Netdisco::JobQueue qw/jq_defer jq_complete/;
 
+sub worker_begin { (shift)->{started} = time }
+
 sub worker_body {
   my $self = shift;
   my $wid = $self->wid;
@@ -38,6 +40,15 @@ sub worker_body {
       };
 
       $self->close_job($job);
+
+      # restart worker once a day.
+      my $hour = [localtime()]->[2];
+      if ($wid) {
+          if ((time >= ($self->{started} + 86400) and $hour == ($wid % 24))
+               or (time > ($self->{started} + 172800))) {
+              $self->exit(0, "recycling worker $wid");
+          }
+      }
   }
 }
 
